Module: Yobi

Defined in:
lib/yobi/version.rb,
lib/yobi/mount.rb,
lib/yobi/errors.rb,
lib/yobi/restic.rb,
lib/yobi/snapshot.rb,
lib/yobi/io_handle.rb,
lib/yobi/repository.rb,
lib/yobi/argv_builder.rb,
lib/yobi/repository/ls.rb,
lib/yobi/restic_output.rb,
lib/yobi/repository/cat.rb,
lib/yobi/repository/key.rb,
lib/yobi/repository/tag.rb,
lib/yobi/repository/copy.rb,
lib/yobi/repository/diff.rb,
lib/yobi/repository/dump.rb,
lib/yobi/repository/find.rb,
lib/yobi/repository/list.rb,
lib/yobi/repository/check.rb,
lib/yobi/repository/mount.rb,
lib/yobi/repository/prune.rb,
lib/yobi/repository/stats.rb,
lib/yobi/repository/backup.rb,
lib/yobi/repository/forget.rb,
lib/yobi/repository/repair.rb,
lib/yobi/repository/unlock.rb,
lib/yobi/repository/migrate.rb,
lib/yobi/repository/recover.rb,
lib/yobi/repository/restore.rb,
lib/yobi/repository/rewrite.rb,
lib/yobi/repository/snapshots.rb,
sig/yobi.rbs

Overview

A Ruby library for the Restic backup tool, wrapping the restic CLI in plain Ruby objects instead of shelling out to flags and raw JSON by hand.

Defined Under Namespace

Classes: ArgvBuilder, AuthenticationFailed, BackupError, BackupErrors, BackupOutcome, BackupStatus, BackupVerboseStatus, CheckError, CheckErrors, CheckOutcome, DiffChange, DiffChanges, DiffOutcome, Error, ExitError, FindMatch, FindMatches, ForgetGroup, ForgetGroups, ForgetReason, IOHandle, Key, Keys, LsEntries, LsEntry, LsOutcome, MatchesPerSnapshot, Mount, MountTimeout, Repository, RepositoryLocked, RepositoryNotFound, Restic, ResticCommandFailed, ResticExecutionError, ResticNotFound, ResticOutput, RestoreOutcome, RestoreStatus, RestoreVerboseStatus, Snapshot, Snapshots, TagChange, TagOutcome, UnsupportedResticVersion

Constant Summary collapse

VERSION =

Returns:

  • (String)
"0.1.0"
MESSAGE_TYPE_LINE_PATTERN =

Captures a line's message_type without fully parsing it as JSON.

/"message_type"\s*:\s*"(\w+)"/