Class: Yobi::RepositoryStats
- Defined in:
- lib/yobi/repository/stats.rb,
sig/yobi.rbs
Overview
The result of one Yobi::Repository#stats call. https://restic.readthedocs.io/en/stable/075_scripting.html#stats
Instance Method Summary collapse
-
#compression_progress ⇒ Float
Percentage of already compressed data.
-
#compression_ratio ⇒ Float
Factor by which the already compressed data has shrunk due to compression.
-
#compression_space_saving ⇒ Float
Overall space saving due to compression.
-
#snapshots_count ⇒ Integer
Number of processed snapshots.
-
#total_blob_count ⇒ Integer
Number of blobs in the repository.
-
#total_file_count ⇒ Integer
Number of files backed up in the repository.
-
#total_size ⇒ Integer
Repository size in bytes.
-
#total_uncompressed_size ⇒ Integer
Repository size in bytes if blobs were uncompressed.
Methods inherited from FancyHash
#initialize, #inspect, #pretty_print
Constructor Details
This class inherits a constructor from Yobi::FancyHash
Instance Method Details
#compression_progress ⇒ Float
Returns percentage of already compressed data.
68 69 70 |
# File 'lib/yobi/repository/stats.rb', line 68 def compression_progress self["compression_progress"] || 0.0 end |
#compression_ratio ⇒ Float
Returns factor by which the already compressed data has shrunk due to compression.
63 64 65 |
# File 'lib/yobi/repository/stats.rb', line 63 def compression_ratio self["compression_ratio"] || 0.0 end |
#compression_space_saving ⇒ Float
Returns overall space saving due to compression.
73 74 75 |
# File 'lib/yobi/repository/stats.rb', line 73 def compression_space_saving self["compression_space_saving"] || 0.0 end |
#snapshots_count ⇒ Integer
Returns number of processed snapshots.
53 54 55 |
# File 'lib/yobi/repository/stats.rb', line 53 def snapshots_count self["snapshots_count"] || 0 end |
#total_blob_count ⇒ Integer
Returns number of blobs in the repository.
48 49 50 |
# File 'lib/yobi/repository/stats.rb', line 48 def total_blob_count self["total_blob_count"] || 0 end |
#total_file_count ⇒ Integer
Returns number of files backed up in the repository.
43 44 45 |
# File 'lib/yobi/repository/stats.rb', line 43 def total_file_count self["total_file_count"] || 0 end |
#total_size ⇒ Integer
Returns repository size in bytes.
38 39 40 |
# File 'lib/yobi/repository/stats.rb', line 38 def total_size self["total_size"] || 0 end |
#total_uncompressed_size ⇒ Integer
Returns repository size in bytes if blobs were uncompressed.
58 59 60 |
# File 'lib/yobi/repository/stats.rb', line 58 def total_uncompressed_size self["total_uncompressed_size"] || 0 end |