Class: Yobi::RepositoryStats

Inherits:
FancyHash
  • Object
show all
Defined in:
lib/yobi/repository/stats.rb,
sig/yobi.rbs

Overview

Instance Method Summary collapse

Methods inherited from FancyHash

#initialize, #inspect, #pretty_print

Constructor Details

This class inherits a constructor from Yobi::FancyHash

Instance Method Details

#compression_progressFloat

Returns percentage of already compressed data.

Returns:

  • (Float)

    percentage of already compressed data



70
71
72
# File 'lib/yobi/repository/stats.rb', line 70

def compression_progress
  self["compression_progress"] || 0.0
end

#compression_ratioFloat

Returns factor by which the already compressed data has shrunk due to compression.

Returns:

  • (Float)

    factor by which the already compressed data has shrunk due to compression



65
66
67
# File 'lib/yobi/repository/stats.rb', line 65

def compression_ratio
  self["compression_ratio"] || 0.0
end

#compression_space_savingFloat

Returns overall space saving due to compression.

Returns:

  • (Float)

    overall space saving due to compression



75
76
77
# File 'lib/yobi/repository/stats.rb', line 75

def compression_space_saving
  self["compression_space_saving"] || 0.0
end

#snapshots_countInteger

Returns number of processed snapshots.

Returns:

  • (Integer)

    number of processed snapshots



55
56
57
# File 'lib/yobi/repository/stats.rb', line 55

def snapshots_count
  self["snapshots_count"] || 0
end

#total_blob_countInteger

Returns number of blobs in the repository.

Returns:

  • (Integer)

    number of blobs in the repository



50
51
52
# File 'lib/yobi/repository/stats.rb', line 50

def total_blob_count
  self["total_blob_count"] || 0
end

#total_file_countInteger

Returns number of files backed up in the repository.

Returns:

  • (Integer)

    number of files backed up in the repository



45
46
47
# File 'lib/yobi/repository/stats.rb', line 45

def total_file_count
  self["total_file_count"] || 0
end

#total_sizeInteger

Returns repository size in bytes.

Returns:

  • (Integer)

    repository size in bytes



40
41
42
# File 'lib/yobi/repository/stats.rb', line 40

def total_size
  self["total_size"] || 0
end

#total_uncompressed_sizeInteger

Returns repository size in bytes if blobs were uncompressed.

Returns:

  • (Integer)

    repository size in bytes if blobs were uncompressed



60
61
62
# File 'lib/yobi/repository/stats.rb', line 60

def total_uncompressed_size
  self["total_uncompressed_size"] || 0
end