Class: Yobi::ResticVersion
- Defined in:
- lib/yobi/restic.rb,
sig/yobi.rbs
Overview
The result of one Yobi::Restic#version call.
Instance Method Summary collapse
-
#go_arch ⇒ String?
The CPU architecture Restic was built for, if reported.
-
#go_os ⇒ String?
The OS Restic was built for, if reported.
-
#go_version ⇒ String?
The Go compiler version Restic was built with, if reported.
-
#version ⇒ String
The Restic version string, e.g.
Methods inherited from FancyHash
#initialize, #inspect, #pretty_print
Constructor Details
This class inherits a constructor from Yobi::FancyHash
Instance Method Details
#go_arch ⇒ String?
The CPU architecture Restic was built for, if reported.
341 342 343 |
# File 'lib/yobi/restic.rb', line 341 def go_arch self["go_arch"] end |
#go_os ⇒ String?
The OS Restic was built for, if reported.
336 337 338 |
# File 'lib/yobi/restic.rb', line 336 def go_os self["go_os"] end |
#go_version ⇒ String?
The Go compiler version Restic was built with, if reported.
331 332 333 |
# File 'lib/yobi/restic.rb', line 331 def go_version self["go_version"] end |
#version ⇒ String
The Restic version string, e.g. "0.19.1".
326 327 328 |
# File 'lib/yobi/restic.rb', line 326 def version self["version"] end |